{*
 * << Haru Free PDF Library 2.0.3 >> -- hpdf.pas
 *
 * Copyright (c) 1999-2006 Takeshi Kanno <takeshi_kanno@est.hi-ho.ne.jp>
 *
 * Permission to use, copy, modify, distribute and sell this software
 * and its documentation for any purpose is hereby granted without fee,
 * provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear
 * in supporting documentation.
 * It is provided "as is" without express or implied warranty.
 *
 * 2014/08/30 Changed "String" to "AnsiString" by Mr.XRAY
 *
 *}

unit hpdf_consts;

interface

uses
  hpdf_types;

const
  HPDF_TRUE = 1;
  HPDF_FALSE = 0;

  HPDF_OK = 0;
  HPDF_NOERROR = 0;

{*----- default values -------------------------------------------------------*}

{* buffer size which is required when we convert to character string. *}
  HPDF_TMP_BUF_SIZ = 256;
  HPDF_SHORT_BUF_SIZ = 32;
  HPDF_REAL_LEN = 11;
  HPDF_INT_LEN = 11;
  HPDF_TEXT_DEFAULT_LEN = 256;
  HPDF_UNICODE_HEADER_LEN = 2;
  HPDF_DATE_TIME_STR_LEN = 23;

{* length of each item defined in PDF *}
  HPDF_BYTE_OFFSET_LEN = 10;
  HPDF_OBJ_ID_LEN = 7;
  HPDF_GEN_NO_LEN = 5;

{* default value of Graphic State *}
  HPDF_DEF_FONT: string = 'Helvetica';
  HPDF_DEF_PAGE_LAYOUT = HPDF_PAGE_LAYOUT_SINGLE;
  HPDF_DEF_PAGE_MODE = HPDF_PAGE_MODE_USE_NONE;
  HPDF_DEF_WORDSPACE= 0;
  HPDF_DEF_CHARSPACE= 0;
  HPDF_DEF_FONTSIZE = 10;
  HPDF_DEF_HSCALING = 100;
  HPDF_DEF_LEADING= 0;
  HPDF_DEF_RENDERING_MODE = HPDF_FILL;
  HPDF_DEF_RAISE= 0;
  HPDF_DEF_LINEWIDTH = 1;
  HPDF_DEF_LINECAP =  HPDF_BUTT_END;
  HPDF_DEF_LINEJOIN = HPDF_MITER_JOIN;
  HPDF_DEF_MITERLIMIT = 10;
  HPDF_DEF_FLATNESS = 1;
  HPDF_DEF_PAGE_NUM = 1;

  HPDF_BS_DEF_WIDTH = 1;

{* defalt page-size *}
  HPDF_DEF_PAGE_WIDTH = 595.276;
  HPDF_DEF_PAGE_HEIGHT = 841.89;

  HPDF_VERSION_TEXT: string = '2.0.3';

{*---------------------------------------------------------------------------*}
{*----- compression mode ----------------------------------------------------*}

  HPDF_COMP_NONE = $00;
  HPDF_COMP_TEXT = $01;
  HPDF_COMP_IMAGE = $02;
  HPDF_COMP_METADATA = $04;
  HPDF_COMP_ALL = $0F;
{*  HPDF_COMP_BEST_COMPRESS = $10;
 *  HPDF_COMP_BEST_SPEED = $20;
 *}
  HPDF_COMP_MASK = $FF;

{*----------------------------------------------------------------------------*}
{*----- permission flags (only Revision 2 is supported)-----------------------*}

  HPDF_ENABLE_READ = 0;
  HPDF_ENABLE_PRINT = 4;
  HPDF_ENABLE_EDIT_ALL = 8;
  HPDF_ENABLE_COPY = 16;
  HPDF_ENABLE_EDIT = 32;


{*----------------------------------------------------------------------------*}
{*------ viewer preferences definitions --------------------------------------*}

  HPDF_HIDE_TOOLBAR = 1;
  HPDF_HIDE_MENUBAR = 2;
  HPDF_HIDE_WINDOW_UI = 4;
  HPDF_FIT_WINDOW = 8;
  HPDF_CENTER_WINDOW = 16;


{*---------------------------------------------------------------------------*}
{*------ limitation of object implementation (PDF1.4) -----------------------*}

  HPDF_LIMIT_MAX_INT = 2147483647;
  HPDF_LIMIT_MIN_INT = -2147483647;

  HPDF_LIMIT_MAX_REAL = 32767;
  HPDF_LIMIT_MIN_REAL = -32767;

  HPDF_LIMIT_MAX_STRING_LEN = 65535;
  HPDF_LIMIT_MAX_NAME_LEN = 127;

  HPDF_LIMIT_MAX_ARRAY = 8191;
  HPDF_LIMIT_MAX_DICT_ELEMENT = 4095;
  HPDF_LIMIT_MAX_XREF_ELEMENT = 8388607;
  HPDF_LIMIT_MAX_GSTATE = 28;
  HPDF_LIMIT_MAX_DEVICE_N = 8;
  HPDF_LIMIT_MAX_DEVICE_N_V15 = 32;
  HPDF_LIMIT_MAX_CID = 65535;
  HPDF_MAX_GENERATION_NUM = 65535;

  HPDF_MIN_PAGE_HEIGHT = 3;
  HPDF_MIN_PAGE_WIDTH = 3;
  HPDF_MAX_PAGE_HEIGHT = 14400;
  HPDF_MAX_PAGE_WIDTH = 14400;
  HPDF_MIN_MAGNIFICATION_FACTOR = 8;
  HPDF_MAX_MAGNIFICATION_FACTOR = 3200;

{*---------------------------------------------------------------------------*}
{*------ limitation of various properties -----------------------------------*}

  HPDF_MIN_PAGE_SIZE = 3;
  HPDF_MAX_PAGE_SIZE = 14400;
  HPDF_MIN_HORIZONTALSCALING = 10;
  HPDF_MAX_HORIZONTALSCALING = 300;
  HPDF_MIN_WORDSPACE = -30;
  HPDF_MAX_WORDSPACE = 300;
  HPDF_MIN_CHARSPACE = -30;
  HPDF_MAX_CHARSPACE = 300;
  HPDF_MAX_FONTSIZE = 300;
  HPDF_MAX_ZOOMSIZE = 10;
  HPDF_MAX_LEADING = 300;
  HPDF_MAX_LINEWIDTH = 100;
  HPDF_MAX_DASH_PATTERN = 100;

{*----------------------------------------------------------------------------*}
{*----- country code definition ----------------------------------------------*}

  HPDF_COUNTRY_AF: AnsiString = 'AF';    {* AFGHANISTAN *}
  HPDF_COUNTRY_AL: AnsiString = 'AL';    {* ALBANIA *}
  HPDF_COUNTRY_DZ: AnsiString = 'DZ';    {* ALGERIA *}
  HPDF_COUNTRY_AS: AnsiString = 'AS';    {* AMERICAN SAMOA *}
  HPDF_COUNTRY_AD: AnsiString = 'AD';    {* ANDORRA *}
  HPDF_COUNTRY_AO: AnsiString = 'AO';    {* ANGOLA *}
  HPDF_COUNTRY_AI: AnsiString = 'AI';    {* ANGUILLA *}
  HPDF_COUNTRY_AQ: AnsiString = 'AQ';    {* ANTARCTICA *}
  HPDF_COUNTRY_AG: AnsiString = 'AG';    {* ANTIGUA AND BARBUDA *}
  HPDF_COUNTRY_AR: AnsiString = 'AR';    {* ARGENTINA *}
  HPDF_COUNTRY_AM: AnsiString = 'AM';    {* ARMENIA *}
  HPDF_COUNTRY_AW: AnsiString = 'AW';    {* ARUBA *}
  HPDF_COUNTRY_AU: AnsiString = 'AU';    {* AUSTRALIA *}
  HPDF_COUNTRY_AT: AnsiString = 'AT';    {* AUSTRIA *}
  HPDF_COUNTRY_AZ: AnsiString = 'AZ';    {* AZERBAIJAN *}
  HPDF_COUNTRY_BS: AnsiString = 'BS';    {* BAHAMAS *}
  HPDF_COUNTRY_BH: AnsiString = 'BH';    {* BAHRAIN *}
  HPDF_COUNTRY_BD: AnsiString = 'BD';    {* BANGLADESH *}
  HPDF_COUNTRY_BB: AnsiString = 'BB';    {* BARBADOS *}
  HPDF_COUNTRY_BY: AnsiString = 'BY';    {* BELARUS *}
  HPDF_COUNTRY_BE: AnsiString = 'BE';    {* BELGIUM *}
  HPDF_COUNTRY_BZ: AnsiString = 'BZ';    {* BELIZE *}
  HPDF_COUNTRY_BJ: AnsiString = 'BJ';    {* BENIN *}
  HPDF_COUNTRY_BM: AnsiString = 'BM';    {* BERMUDA *}
  HPDF_COUNTRY_BT: AnsiString = 'BT';    {* BHUTAN *}
  HPDF_COUNTRY_BO: AnsiString = 'BO';    {* BOLIVIA *}
  HPDF_COUNTRY_BA: AnsiString = 'BA';    {* BOSNIA AND HERZEGOWINA *}
  HPDF_COUNTRY_BW: AnsiString = 'BW';    {* BOTSWANA *}
  HPDF_COUNTRY_BV: AnsiString = 'BV';    {* BOUVET ISLAND *}
  HPDF_COUNTRY_BR: AnsiString = 'BR';    {* BRAZIL *}
  HPDF_COUNTRY_IO: AnsiString = 'IO';    {* BRITISH INDIAN OCEAN TERRITORY *}
  HPDF_COUNTRY_BN: AnsiString = 'BN';    {* BRUNEI DARUSSALAM *}
  HPDF_COUNTRY_BG: AnsiString = 'BG';    {* BULGARIA *}
  HPDF_COUNTRY_BF: AnsiString = 'BF';    {* BURKINA FASO *}
  HPDF_COUNTRY_BI: AnsiString = 'BI';    {* BURUNDI *}
  HPDF_COUNTRY_KH: AnsiString = 'KH';    {* CAMBODIA *}
  HPDF_COUNTRY_CM: AnsiString = 'CM';    {* CAMEROON *}
  HPDF_COUNTRY_CA: AnsiString = 'CA';    {* CANADA *}
  HPDF_COUNTRY_CV: AnsiString = 'CV';    {* CAPE VERDE *}
  HPDF_COUNTRY_KY: AnsiString = 'KY';    {* CAYMAN ISLANDS *}
  HPDF_COUNTRY_CF: AnsiString = 'CF';    {* CENTRAL AFRICAN REPUBLIC *}
  HPDF_COUNTRY_TD: AnsiString = 'TD';    {* CHAD *}
  HPDF_COUNTRY_CL: AnsiString = 'CL';    {* CHILE *}
  HPDF_COUNTRY_CN: AnsiString = 'CN';    {* CHINA *}
  HPDF_COUNTRY_CX: AnsiString = 'CX';    {* CHRISTMAS ISLAND *}
  HPDF_COUNTRY_CC: AnsiString = 'CC';    {* COCOS (KEELING) ISLANDS *}
  HPDF_COUNTRY_CO: AnsiString = 'CO';    {* COLOMBIA *}
  HPDF_COUNTRY_KM: AnsiString = 'KM';    {* COMOROS *}
  HPDF_COUNTRY_CG: AnsiString = 'CG';    {* CONGO *}
  HPDF_COUNTRY_CK: AnsiString = 'CK';    {* COOK ISLANDS *}
  HPDF_COUNTRY_CR: AnsiString = 'CR';    {* COSTA RICA *}
  HPDF_COUNTRY_CI: AnsiString = 'CI';    {* COTE D'IVOIRE *}
  HPDF_COUNTRY_HR: AnsiString = 'HR';    {* CROATIA (local name: Hrvatska) *}
  HPDF_COUNTRY_CU: AnsiString = 'CU';    {* CUBA *}
  HPDF_COUNTRY_CY: AnsiString = 'CY';    {* CYPRUS *}
  HPDF_COUNTRY_CZ: AnsiString = 'CZ';    {* CZECH REPUBLIC *}
  HPDF_COUNTRY_DK: AnsiString = 'DK';    {* DENMARK *}
  HPDF_COUNTRY_DJ: AnsiString = 'DJ';    {* DJIBOUTI *}
  HPDF_COUNTRY_DM: AnsiString = 'DM';    {* DOMINICA *}
  HPDF_COUNTRY_DO: AnsiString = 'DO';    {* DOMINICAN REPUBLIC *}
  HPDF_COUNTRY_TP: AnsiString = 'TP';    {* EAST TIMOR *}
  HPDF_COUNTRY_EC: AnsiString = 'EC';    {* ECUADOR *}
  HPDF_COUNTRY_EG: AnsiString = 'EG';    {* EGYPT *}
  HPDF_COUNTRY_SV: AnsiString = 'SV';    {* EL SALVADOR *}
  HPDF_COUNTRY_GQ: AnsiString = 'GQ';    {* EQUATORIAL GUINEA *}
  HPDF_COUNTRY_ER: AnsiString = 'ER';    {* ERITREA *}
  HPDF_COUNTRY_EE: AnsiString = 'EE';    {* ESTONIA *}
  HPDF_COUNTRY_ET: AnsiString = 'ET';    {* ETHIOPIA *}
  HPDF_COUNTRY_FK: AnsiString = 'FK';    {* FALKLAND ISLANDS (MALVINAS) *}
  HPDF_COUNTRY_FO: AnsiString = 'FO';    {* FAROE ISLANDS *}
  HPDF_COUNTRY_FJ: AnsiString = 'FJ';    {* FIJI *}
  HPDF_COUNTRY_FI: AnsiString = 'FI';    {* FINLAND *}
  HPDF_COUNTRY_FR: AnsiString = 'FR';    {* FRANCE *}
  HPDF_COUNTRY_FX: AnsiString = 'FX';    {* FRANCE, METROPOLITAN *}
  HPDF_COUNTRY_GF: AnsiString = 'GF';    {* FRENCH GUIANA *}
  HPDF_COUNTRY_PF: AnsiString = 'PF';    {* FRENCH POLYNESIA *}
  HPDF_COUNTRY_TF: AnsiString = 'TF';    {* FRENCH SOUTHERN TERRITORIES *}
  HPDF_COUNTRY_GA: AnsiString = 'GA';    {* GABON *}
  HPDF_COUNTRY_GM: AnsiString = 'GM';    {* GAMBIA *}
  HPDF_COUNTRY_GE: AnsiString = 'GE';    {* GEORGIA *}
  HPDF_COUNTRY_DE: AnsiString = 'DE';    {* GERMANY *}
  HPDF_COUNTRY_GH: AnsiString = 'GH';    {* GHANA *}
  HPDF_COUNTRY_GI: AnsiString = 'GI';    {* GIBRALTAR *}
  HPDF_COUNTRY_GR: AnsiString = 'GR';    {* GREECE *}
  HPDF_COUNTRY_GL: AnsiString = 'GL';    {* GREENLAND *}
  HPDF_COUNTRY_GD: AnsiString = 'GD';    {* GRENADA *}
  HPDF_COUNTRY_GP: AnsiString = 'GP';    {* GUADELOUPE *}
  HPDF_COUNTRY_GU: AnsiString = 'GU';    {* GUAM *}
  HPDF_COUNTRY_GT: AnsiString = 'GT';    {* GUATEMALA *}
  HPDF_COUNTRY_GN: AnsiString = 'GN';    {* GUINEA *}
  HPDF_COUNTRY_GW: AnsiString = 'GW';    {* GUINEA-BISSAU *}
  HPDF_COUNTRY_GY: AnsiString = 'GY';    {* GUYANA *}
  HPDF_COUNTRY_HT: AnsiString = 'HT';    {* HAITI *}
  HPDF_COUNTRY_HM: AnsiString = 'HM';    {* HEARD AND MC DONALD ISLANDS *}
  HPDF_COUNTRY_HN: AnsiString = 'HN';    {* HONDURAS *}
  HPDF_COUNTRY_HK: AnsiString = 'HK';    {* HONG KONG *}
  HPDF_COUNTRY_HU: AnsiString = 'HU';    {* HUNGARY *}
  HPDF_COUNTRY_IS: AnsiString = 'IS';    {* ICELAND *}
  HPDF_COUNTRY_IN: AnsiString = 'IN';    {* INDIA *}
  HPDF_COUNTRY_ID: AnsiString = 'ID';    {* INDONESIA *}
  HPDF_COUNTRY_IR: AnsiString = 'IR';    {* IRAN (ISLAMIC REPUBLIC OF) *}
  HPDF_COUNTRY_IQ: AnsiString = 'IQ';    {* IRAQ *}
  HPDF_COUNTRY_IE: AnsiString = 'IE';    {* IRELAND *}
  HPDF_COUNTRY_IL: AnsiString = 'IL';    {* ISRAEL *}
  HPDF_COUNTRY_IT: AnsiString = 'IT';    {* ITALY *}
  HPDF_COUNTRY_JM: AnsiString = 'JM';    {* JAMAICA *}
  HPDF_COUNTRY_JP: AnsiString = 'JP';    {* JAPAN *}
  HPDF_COUNTRY_JO: AnsiString = 'JO';    {* JORDAN *}
  HPDF_COUNTRY_KZ: AnsiString = 'KZ';    {* KAZAKHSTAN *}
  HPDF_COUNTRY_KE: AnsiString = 'KE';    {* KENYA *}
  HPDF_COUNTRY_KI: AnsiString = 'KI';    {* KIRIBATI *}
  HPDF_COUNTRY_KP: AnsiString = 'KP';    {* KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF *}
  HPDF_COUNTRY_KR: AnsiString = 'KR';    {* KOREA, REPUBLIC OF *}
  HPDF_COUNTRY_KW: AnsiString = 'KW';    {* KUWAIT *}
  HPDF_COUNTRY_KG: AnsiString = 'KG';    {* KYRGYZSTAN *}
  HPDF_COUNTRY_LA: AnsiString = 'LA';    {* LAO PEOPLE'S DEMOCRATIC REPUBLIC *}
  HPDF_COUNTRY_LV: AnsiString = 'LV';    {* LATVIA *}
  HPDF_COUNTRY_LB: AnsiString = 'LB';    {* LEBANON *}
  HPDF_COUNTRY_LS: AnsiString = 'LS';    {* LESOTHO *}
  HPDF_COUNTRY_LR: AnsiString = 'LR';    {* LIBERIA *}
  HPDF_COUNTRY_LY: AnsiString = 'LY';    {* LIBYAN ARAB JAMAHIRIYA *}
  HPDF_COUNTRY_LI: AnsiString = 'LI';    {* LIECHTENSTEIN *}
  HPDF_COUNTRY_LT: AnsiString = 'LT';    {* LITHUANIA *}
  HPDF_COUNTRY_LU: AnsiString = 'LU';    {* LUXEMBOURG *}
  HPDF_COUNTRY_MO: AnsiString = 'MO';    {* MACAU *}
  HPDF_COUNTRY_MK: AnsiString = 'MK';    {* MACEDONIA,THE FORMER YUGOSLAV REPUBLIC OF *}
  HPDF_COUNTRY_MG: AnsiString = 'MG';    {* MADAGASCAR *}
  HPDF_COUNTRY_MW: AnsiString = 'MW';    {* MALAWI *}
  HPDF_COUNTRY_MY: AnsiString = 'MY';    {* MALAYSIA *}
  HPDF_COUNTRY_MV: AnsiString = 'MV';    {* MALDIVES *}
  HPDF_COUNTRY_ML: AnsiString = 'ML';    {* MALI *}
  HPDF_COUNTRY_MT: AnsiString = 'MT';    {* MALTA *}
  HPDF_COUNTRY_MH: AnsiString = 'MH';    {* MARSHALL ISLANDS *}
  HPDF_COUNTRY_MQ: AnsiString = 'MQ';    {* MARTINIQUE *}
  HPDF_COUNTRY_MR: AnsiString = 'MR';    {* MAURITANIA *}
  HPDF_COUNTRY_MU: AnsiString = 'MU';    {* MAURITIUS *}
  HPDF_COUNTRY_YT: AnsiString = 'YT';    {* MAYOTTE *}
  HPDF_COUNTRY_MX: AnsiString = 'MX';    {* MEXICO *}
  HPDF_COUNTRY_FM: AnsiString = 'FM';    {* MICRONESIA, FEDERATED STATES OF *}
  HPDF_COUNTRY_MD: AnsiString = 'MD';    {* MOLDOVA, REPUBLIC OF *}
  HPDF_COUNTRY_MC: AnsiString = 'MC';    {* MONACO *}
  HPDF_COUNTRY_MN: AnsiString = 'MN';    {* MONGOLIA *}
  HPDF_COUNTRY_MS: AnsiString = 'MS';    {* MONTSERRAT *}
  HPDF_COUNTRY_MA: AnsiString = 'MA';    {* MOROCCO *}
  HPDF_COUNTRY_MZ: AnsiString = 'MZ';    {* MOZAMBIQUE *}
  HPDF_COUNTRY_MM: AnsiString = 'MM';    {* MYANMAR *}
  HPDF_COUNTRY_NA: AnsiString = 'NA';    {* NAMIBIA *}
  HPDF_COUNTRY_NR: AnsiString = 'NR';    {* NAURU *}
  HPDF_COUNTRY_NP: AnsiString = 'NP';    {* NEPAL *}
  HPDF_COUNTRY_NL: AnsiString = 'NL';    {* NETHERLANDS *}
  HPDF_COUNTRY_AN: AnsiString = 'AN';    {* NETHERLANDS ANTILLES *}
  HPDF_COUNTRY_NC: AnsiString = 'NC';    {* NEW CALEDONIA *}
  HPDF_COUNTRY_NZ: AnsiString = 'NZ';    {* NEW ZEALAND *}
  HPDF_COUNTRY_NI: AnsiString = 'NI';    {* NICARAGUA *}
  HPDF_COUNTRY_NE: AnsiString = 'NE';    {* NIGER *}
  HPDF_COUNTRY_NG: AnsiString = 'NG';    {* NIGERIA *}
  HPDF_COUNTRY_NU: AnsiString = 'NU';    {* NIUE *}
  HPDF_COUNTRY_NF: AnsiString = 'NF';    {* NORFOLK ISLAND *}
  HPDF_COUNTRY_MP: AnsiString = 'MP';    {* NORTHERN MARIANA ISLANDS *}
  HPDF_COUNTRY_NO: AnsiString = 'NO';    {* NORWAY *}
  HPDF_COUNTRY_OM: AnsiString = 'OM';    {* OMAN *}
  HPDF_COUNTRY_PK: AnsiString = 'PK';    {* PAKISTAN *}
  HPDF_COUNTRY_PW: AnsiString = 'PW';    {* PALAU *}
  HPDF_COUNTRY_PA: AnsiString = 'PA';    {* PANAMA *}
  HPDF_COUNTRY_PG: AnsiString = 'PG';    {* PAPUA NEW GUINEA *}
  HPDF_COUNTRY_PY: AnsiString = 'PY';    {* PARAGUAY *}
  HPDF_COUNTRY_PE: AnsiString = 'PE';    {* PERU *}
  HPDF_COUNTRY_PH: AnsiString = 'PH';    {* PHILIPPINES *}
  HPDF_COUNTRY_PN: AnsiString = 'PN';    {* PITCAIRN *}
  HPDF_COUNTRY_PL: AnsiString = 'PL';    {* POLAND *}
  HPDF_COUNTRY_PT: AnsiString = 'PT';    {* PORTUGAL *}
  HPDF_COUNTRY_PR: AnsiString = 'PR';    {* PUERTO RICO *}
  HPDF_COUNTRY_QA: AnsiString = 'QA';    {* QATAR *}
  HPDF_COUNTRY_RE: AnsiString = 'RE';    {* REUNION *}
  HPDF_COUNTRY_RO: AnsiString = 'RO';    {* ROMANIA *}
  HPDF_COUNTRY_RU: AnsiString = 'RU';    {* RUSSIAN FEDERATION *}
  HPDF_COUNTRY_RW: AnsiString = 'RW';    {* RWANDA *}
  HPDF_COUNTRY_KN: AnsiString = 'KN';    {* SAINT KITTS AND NEVIS *}
  HPDF_COUNTRY_LC: AnsiString = 'LC';    {* SAINT LUCIA *}
  HPDF_COUNTRY_VC: AnsiString = 'VC';    {* SAINT VINCENT AND THE GRENADINES *}
  HPDF_COUNTRY_WS: AnsiString = 'WS';    {* SAMOA *}
  HPDF_COUNTRY_SM: AnsiString = 'SM';    {* SAN MARINO *}
  HPDF_COUNTRY_ST: AnsiString = 'ST';    {* SAO TOME AND PRINCIPE *}
  HPDF_COUNTRY_SA: AnsiString = 'SA';    {* SAUDI ARABIA *}
  HPDF_COUNTRY_SN: AnsiString = 'SN';    {* SENEGAL *}
  HPDF_COUNTRY_SC: AnsiString = 'SC';    {* SEYCHELLES *}
  HPDF_COUNTRY_SL: AnsiString = 'SL';    {* SIERRA LEONE *}
  HPDF_COUNTRY_SG: AnsiString = 'SG';    {* SINGAPORE *}
  HPDF_COUNTRY_SK: AnsiString = 'SK';    {* SLOVAKIA (Slovak Republic) *}
  HPDF_COUNTRY_SI: AnsiString = 'SI';    {* SLOVENIA *}
  HPDF_COUNTRY_SB: AnsiString = 'SB';    {* SOLOMON ISLANDS *}
  HPDF_COUNTRY_SO: AnsiString = 'SO';    {* SOMALIA *}
  HPDF_COUNTRY_ZA: AnsiString = 'ZA';    {* SOUTH AFRICA *}
  HPDF_COUNTRY_ES: AnsiString = 'ES';    {* SPAIN *}
  HPDF_COUNTRY_LK: AnsiString = 'LK';    {* SRI LANKA *}
  HPDF_COUNTRY_SH: AnsiString = 'SH';    {* ST. HELENA *}
  HPDF_COUNTRY_PM: AnsiString = 'PM';    {* ST. PIERRE AND MIQUELON *}
  HPDF_COUNTRY_SD: AnsiString = 'SD';    {* SUDAN *}
  HPDF_COUNTRY_SR: AnsiString = 'SR';    {* SURINAME *}
  HPDF_COUNTRY_SJ: AnsiString = 'SJ';    {* SVALBARD AND JAN MAYEN ISLANDS *}
  HPDF_COUNTRY_SZ: AnsiString = 'SZ';    {* SWAZILAND *}
  HPDF_COUNTRY_SE: AnsiString = 'SE';    {* SWEDEN *}
  HPDF_COUNTRY_CH: AnsiString = 'CH';    {* SWITZERLAND *}
  HPDF_COUNTRY_SY: AnsiString = 'SY';    {* SYRIAN ARAB REPUBLIC *}
  HPDF_COUNTRY_TW: AnsiString = 'TW';    {* TAIWAN, PROVINCE OF CHINA *}
  HPDF_COUNTRY_TJ: AnsiString = 'TJ';    {* TAJIKISTAN *}
  HPDF_COUNTRY_TZ: AnsiString = 'TZ';    {* TANZANIA, UNITED REPUBLIC OF *}
  HPDF_COUNTRY_TH: AnsiString = 'TH';    {* THAILAND *}
  HPDF_COUNTRY_TG: AnsiString = 'TG';    {* TOGO *}
  HPDF_COUNTRY_TK: AnsiString = 'TK';    {* TOKELAU *}
  HPDF_COUNTRY_TO: AnsiString = 'TO';    {* TONGA *}
  HPDF_COUNTRY_TT: AnsiString = 'TT';    {* TRINIDAD AND TOBAGO *}
  HPDF_COUNTRY_TN: AnsiString = 'TN';    {* TUNISIA *}
  HPDF_COUNTRY_TR: AnsiString = 'TR';    {* TURKEY *}
  HPDF_COUNTRY_TM: AnsiString = 'TM';    {* TURKMENISTAN *}
  HPDF_COUNTRY_TC: AnsiString = 'TC';    {* TURKS AND CAICOS ISLANDS *}
  HPDF_COUNTRY_TV: AnsiString = 'TV';    {* TUVALU *}
  HPDF_COUNTRY_UG: AnsiString = 'UG';    {* UGANDA *}
  HPDF_COUNTRY_UA: AnsiString = 'UA';    {* UKRAINE *}
  HPDF_COUNTRY_AE: AnsiString = 'AE';    {* UNITED ARAB EMIRATES *}
  HPDF_COUNTRY_GB: AnsiString = 'GB';    {* UNITED KINGDOM *}
  HPDF_COUNTRY_US: AnsiString = 'US';    {* UNITED STATES *}
  HPDF_COUNTRY_UM: AnsiString = 'UM';    {* UNITED STATES MINOR OUTLYING ISLANDS *}
  HPDF_COUNTRY_UY: AnsiString = 'UY';    {* URUGUAY *}
  HPDF_COUNTRY_UZ: AnsiString = 'UZ';    {* UZBEKISTAN *}
  HPDF_COUNTRY_VU: AnsiString = 'VU';    {* VANUATU *}
  HPDF_COUNTRY_VA: AnsiString = 'VA';    {* VATICAN CITY STATE (HOLY SEE) *}
  HPDF_COUNTRY_VE: AnsiString = 'VE';    {* VENEZUELA *}
  HPDF_COUNTRY_VN: AnsiString = 'VN';    {* VIET NAM *}
  HPDF_COUNTRY_VG: AnsiString = 'VG';    {* VIRGIN ISLANDS (BRITISH) *}
  HPDF_COUNTRY_VI: AnsiString = 'VI';    {* VIRGIN ISLANDS (U.S.) *}
  HPDF_COUNTRY_WF: AnsiString = 'WF';    {* WALLIS AND FUTUNA ISLANDS *}
  HPDF_COUNTRY_EH: AnsiString = 'EH';    {* WESTERN SAHARA *}
  HPDF_COUNTRY_YE: AnsiString = 'YE';    {* YEMEN *}
  HPDF_COUNTRY_YU: AnsiString = 'YU';    {* YUGOSLAVIA *}
  HPDF_COUNTRY_ZR: AnsiString = 'ZR';    {* ZAIRE *}
  HPDF_COUNTRY_ZM: AnsiString = 'ZM';    {* ZAMBIA *}
  HPDF_COUNTRY_ZW: AnsiString = 'ZW';    {* ZIMBABWE *}

{*----------------------------------------------------------------------------*}
{*----- lang code definition -------------------------------------------------*}

  HPDF_LANG_AA: AnsiString = 'aa';    {* Afar *}
  HPDF_LANG_AB: AnsiString = 'ab';    {* Abkhazian *}
  HPDF_LANG_AF: AnsiString = 'af';    {* Afrikaans *}
  HPDF_LANG_AM: AnsiString = 'am';    {* Amharic *}
  HPDF_LANG_AR: AnsiString = 'ar';    {* Arabic *}
  HPDF_LANG_AS: AnsiString = 'as';    {* Assamese *}
  HPDF_LANG_AY: AnsiString = 'ay';    {* Aymara *}
  HPDF_LANG_AZ: AnsiString = 'az';    {* Azerbaijani *}
  HPDF_LANG_BA: AnsiString = 'ba';    {* Bashkir *}
  HPDF_LANG_BE: AnsiString = 'be';    {* Byelorussian *}
  HPDF_LANG_BG: AnsiString = 'bg';    {* Bulgarian *}
  HPDF_LANG_BH: AnsiString = 'bh';    {* Bihari *}
  HPDF_LANG_BI: AnsiString = 'bi';    {* Bislama *}
  HPDF_LANG_BN: AnsiString = 'bn';    {* Bengali Bangla *}
  HPDF_LANG_BO: AnsiString = 'bo';    {* Tibetan *}
  HPDF_LANG_BR: AnsiString = 'br';    {* Breton *}
  HPDF_LANG_CA: AnsiString = 'ca';    {* Catalan *}
  HPDF_LANG_CO: AnsiString = 'co';    {* Corsican *}
  HPDF_LANG_CS: AnsiString = 'cs';    {* Czech *}
  HPDF_LANG_CY: AnsiString = 'cy';    {* Welsh *}
  HPDF_LANG_DA: AnsiString = 'da';    {* Danish *}
  HPDF_LANG_DE: AnsiString = 'de';    {* German *}
  HPDF_LANG_DZ: AnsiString = 'dz';    {* Bhutani *}
  HPDF_LANG_EL: AnsiString = 'el';    {* Greek *}
  HPDF_LANG_EN: AnsiString = 'en';    {* English *}
  HPDF_LANG_EO: AnsiString = 'eo';    {* Esperanto *}
  HPDF_LANG_ES: AnsiString = 'es';    {* Spanish *}
  HPDF_LANG_ET: AnsiString = 'et';    {* Estonian *}
  HPDF_LANG_EU: AnsiString = 'eu';    {* Basque *}
  HPDF_LANG_FA: AnsiString = 'fa';    {* Persian *}
  HPDF_LANG_FI: AnsiString = 'fi';    {* Finnish *}
  HPDF_LANG_FJ: AnsiString = 'fj';    {* Fiji *}
  HPDF_LANG_FO: AnsiString = 'fo';    {* Faeroese *}
  HPDF_LANG_FR: AnsiString = 'fr';    {* French *}
  HPDF_LANG_FY: AnsiString = 'fy';    {* Frisian *}
  HPDF_LANG_GA: AnsiString = 'ga';    {* Irish *}
  HPDF_LANG_GD: AnsiString = 'gd';    {* Scots Gaelic *}
  HPDF_LANG_GL: AnsiString = 'gl';    {* Galician *}
  HPDF_LANG_GN: AnsiString = 'gn';    {* Guarani *}
  HPDF_LANG_GU: AnsiString = 'gu';    {* Gujarati *}
  HPDF_LANG_HA: AnsiString = 'ha';    {* Hausa *}
  HPDF_LANG_HI: AnsiString = 'hi';    {* Hindi *}
  HPDF_LANG_HR: AnsiString = 'hr';    {* Croatian *}
  HPDF_LANG_HU: AnsiString = 'hu';    {* Hungarian *}
  HPDF_LANG_HY: AnsiString = 'hy';    {* Armenian *}
  HPDF_LANG_IA: AnsiString = 'ia';    {* Interlingua *}
  HPDF_LANG_IE: AnsiString = 'ie';    {* Interlingue *}
  HPDF_LANG_IK: AnsiString = 'ik';    {* Inupiak *}
  HPDF_LANG_IN: AnsiString = 'in';    {* Indonesian *}
  HPDF_LANG_IS: AnsiString = 'is';    {* Icelandic *}
  HPDF_LANG_IT: AnsiString = 'it';    {* Italian *}
  HPDF_LANG_IW: AnsiString = 'iw';    {* Hebrew *}
  HPDF_LANG_JA: AnsiString = 'ja';    {* Japanese *}
  HPDF_LANG_JI: AnsiString = 'ji';    {* Yiddish *}
  HPDF_LANG_JW: AnsiString = 'jw';    {* Javanese *}
  HPDF_LANG_KA: AnsiString = 'ka';    {* Georgian *}
  HPDF_LANG_KK: AnsiString = 'kk';    {* Kazakh *}
  HPDF_LANG_KL: AnsiString = 'kl';    {* Greenlandic *}
  HPDF_LANG_KM: AnsiString = 'km';    {* Cambodian *}
  HPDF_LANG_KN: AnsiString = 'kn';    {* Kannada *}
  HPDF_LANG_KO: AnsiString = 'ko';    {* Korean *}
  HPDF_LANG_KS: AnsiString = 'ks';    {* Kashmiri *}
  HPDF_LANG_KU: AnsiString = 'ku';    {* Kurdish *}
  HPDF_LANG_KY: AnsiString = 'ky';    {* Kirghiz *}
  HPDF_LANG_LA: AnsiString = 'la';    {* Latin *}
  HPDF_LANG_LN: AnsiString = 'ln';    {* Lingala *}
  HPDF_LANG_LO: AnsiString = 'lo';    {* Laothian *}
  HPDF_LANG_LT: AnsiString = 'lt';    {* Lithuanian *}
  HPDF_LANG_LV: AnsiString = 'lv';    {* Latvian,Lettish *}
  HPDF_LANG_MG: AnsiString = 'mg';    {* Malagasy *}
  HPDF_LANG_MI: AnsiString = 'mi';    {* Maori *}
  HPDF_LANG_MK: AnsiString = 'mk';    {* Macedonian *}
  HPDF_LANG_ML: AnsiString = 'ml';    {* Malayalam *}
  HPDF_LANG_MN: AnsiString = 'mn';    {* Mongolian *}
  HPDF_LANG_MO: AnsiString = 'mo';    {* Moldavian *}
  HPDF_LANG_MR: AnsiString = 'mr';    {* Marathi *}
  HPDF_LANG_MS: AnsiString = 'ms';    {* Malay *}
  HPDF_LANG_MT: AnsiString = 'mt';    {* Maltese *}
  HPDF_LANG_MY: AnsiString = 'my';    {* Burmese *}
  HPDF_LANG_NA: AnsiString = 'na';    {* Nauru *}
  HPDF_LANG_NE: AnsiString = 'ne';    {* Nepali *}
  HPDF_LANG_NL: AnsiString = 'nl';    {* Dutch *}
  HPDF_LANG_NO: AnsiString = 'no';    {* Norwegian *}
  HPDF_LANG_OC: AnsiString = 'oc';    {* Occitan *}
  HPDF_LANG_OM: AnsiString = 'om';    {* (Afan)Oromo *}
  HPDF_LANG_OR: AnsiString = 'or';    {* Oriya *}
  HPDF_LANG_PA: AnsiString = 'pa';    {* Punjabi *}
  HPDF_LANG_PL: AnsiString = 'pl';    {* Polish *}
  HPDF_LANG_PS: AnsiString = 'ps';    {* Pashto,Pushto *}
  HPDF_LANG_PT: AnsiString = 'pt';    {* Portuguese  *}
  HPDF_LANG_QU: AnsiString = 'qu';    {* Quechua *}
  HPDF_LANG_RM: AnsiString = 'rm';    {* Rhaeto-Romance *}
  HPDF_LANG_RN: AnsiString = 'rn';    {* Kirundi *}
  HPDF_LANG_RO: AnsiString = 'ro';    {* Romanian *}
  HPDF_LANG_RU: AnsiString = 'ru';    {* Russian *}
  HPDF_LANG_RW: AnsiString = 'rw';    {* Kinyarwanda *}
  HPDF_LANG_SA: AnsiString = 'sa';    {* Sanskrit *}
  HPDF_LANG_SD: AnsiString = 'sd';    {* Sindhi *}
  HPDF_LANG_SG: AnsiString = 'sg';    {* Sangro *}
  HPDF_LANG_SH: AnsiString = 'sh';    {* Serbo-Croatian *}
  HPDF_LANG_SI: AnsiString = 'si';    {* Singhalese *}
  HPDF_LANG_SK: AnsiString = 'sk';    {* Slovak *}
  HPDF_LANG_SL: AnsiString = 'sl';    {* Slovenian *}
  HPDF_LANG_SM: AnsiString = 'sm';    {* Samoan *}
  HPDF_LANG_SN: AnsiString = 'sn';    {* Shona *}
  HPDF_LANG_SO: AnsiString = 'so';    {* Somali *}
  HPDF_LANG_SQ: AnsiString = 'sq';    {* Albanian *}
  HPDF_LANG_SR: AnsiString = 'sr';    {* Serbian *}
  HPDF_LANG_SS: AnsiString = 'ss';    {* Siswati *}
  HPDF_LANG_ST: AnsiString = 'st';    {* Sesotho *}
  HPDF_LANG_SU: AnsiString = 'su';    {* Sundanese *}
  HPDF_LANG_SV: AnsiString = 'sv';    {* Swedish *}
  HPDF_LANG_SW: AnsiString = 'sw';    {* Swahili *}
  HPDF_LANG_TA: AnsiString = 'ta';    {* Tamil *}
  HPDF_LANG_TE: AnsiString = 'te';    {* Tegulu *}
  HPDF_LANG_TG: AnsiString = 'tg';    {* Tajik *}
  HPDF_LANG_TH: AnsiString = 'th';    {* Thai *}
  HPDF_LANG_TI: AnsiString = 'ti';    {* Tigrinya *}
  HPDF_LANG_TK: AnsiString = 'tk';    {* Turkmen *}
  HPDF_LANG_TL: AnsiString = 'tl';    {* Tagalog *}
  HPDF_LANG_TN: AnsiString = 'tn';    {* Setswanato Tonga *}
  HPDF_LANG_TR: AnsiString = 'tr';    {* Turkish *}
  HPDF_LANG_TS: AnsiString = 'ts';    {* Tsonga *}
  HPDF_LANG_TT: AnsiString = 'tt';    {* Tatar *}
  HPDF_LANG_TW: AnsiString = 'tw';    {* Twi *}
  HPDF_LANG_UK: AnsiString = 'uk';    {* Ukrainian *}
  HPDF_LANG_UR: AnsiString = 'ur';    {* Urdu *}
  HPDF_LANG_UZ: AnsiString = 'uz';    {* Uzbek *}
  HPDF_LANG_VI: AnsiString = 'vi';    {* Vietnamese *}
  HPDF_LANG_VO: AnsiString = 'vo';    {* Volapuk *}
  HPDF_LANG_WO: AnsiString = 'wo';    {* Wolof *}
  HPDF_LANG_XH: AnsiString = 'xh';    {* Xhosa *}
  HPDF_LANG_YO: AnsiString = 'yo';    {* Yoruba *}
  HPDF_LANG_ZH: AnsiString = 'zh';    {* Chinese *}
  HPDF_LANG_ZU: AnsiString = 'zu';    {* Zulu *}


{*----------------------------------------------------------------------------*}
{*----- Graphis mode ---------------------------------------------------------*}

  HPDF_GMODE_PAGE_DESCRIPTION = $0001;
  HPDF_GMODE_PATH_OBJECT = $0002;
  HPDF_GMODE_TEXT_OBJECT = $0004;
  HPDF_GMODE_CLIPPING_PATH = $0008;
  HPDF_GMODE_SHADING = $0010;
  HPDF_GMODE_INLINE_IMAGE =  $0020;
  HPDF_GMODE_EXTERNAL_OBJECT = $0040;

{*----------------------------------------------------------------------------*}

implementation

end.

